@@ -1,60 +1,65 @@
 use strict;
 use warnings;
+
 package File::pushd;
 # ABSTRACT: change directory temporarily for a limited scope
-our $VERSION = '1.004'; # VERSION
+our $VERSION = '1.006'; # VERSION
 
-our @EXPORT  = qw( pushd tempd );
-our @ISA     = qw( Exporter );
+our @EXPORT = qw( pushd tempd );
+our @ISA    = qw( Exporter );
 
 use Exporter;
 use Carp;
-use Cwd         qw( cwd abs_path );
-use File::Path  qw( rmtree );
-use File::Temp  qw();
+use Cwd qw( getcwd abs_path );
+use File::Path qw( rmtree );
+use File::Temp qw();
 use File::Spec;
 
 use overload
-    q{""} => sub { File::Spec->canonpath( $_[0]->{_pushd} ) },
-    fallback => 1;
+  q{""}    => sub { File::Spec->canonpath( $_[0]->{_pushd} ) },
+  fallback => 1;
 
 #--------------------------------------------------------------------------#
 # pushd()
 #--------------------------------------------------------------------------#
 
 sub pushd {
-    my ($target_dir, $options) = @_;
+    my ( $target_dir, $options ) = @_;
     $options->{untaint_pattern} ||= qr{^([-+@\w./]+)$};
 
-    my $tainted_orig = cwd;
+    $target_dir = "." unless defined $target_dir;
+    croak "Can't locate directory $target_dir" unless -d $target_dir;
+
+    my $tainted_orig = getcwd;
     my $orig;
     if ( $tainted_orig =~ $options->{untaint_pattern} ) {
-      $orig = $1;
+        $orig = $1;
     }
     else {
-      $orig = $tainted_orig;
+        $orig = $tainted_orig;
     }
 
     my $tainted_dest;
-    eval { $tainted_dest   = $target_dir ? abs_path( $target_dir ) : $orig };
-    croak "Can't locate directory $target_dir: $@" if $@;
+    eval { $tainted_dest = $target_dir ? abs_path($target_dir) : $orig };
+    croak "Can't locate absolute path for $target_dir: $@" if $@;
 
     my $dest;
     if ( $tainted_dest =~ $options->{untaint_pattern} ) {
-      $dest = $1;
+        $dest = $1;
     }
     else {
-      $dest = $tainted_dest;
+        $dest = $tainted_dest;
     }
 
-    if ($dest ne $orig) {
+    if ( $dest ne $orig ) {
         chdir $dest or croak "Can't chdir to $dest\: $!";
     }
 
     my $self = bless {
-        _pushd => $dest,
+        _pushd    => $dest,
         _original => $orig
-    }, __PACKAGE__;
+      },
+      __PACKAGE__;
 
     return $self;
 }
@@ -78,7 +83,7 @@ sub tempd {
 
 sub preserve {
     my $self = shift;
-    return 1 if ! $self->{"_tempd"};
+    return 1 if !$self->{"_tempd"};
     if ( @_ == 0 ) {
         return $self->{_preserve} = 1;
     }
@@ -97,8 +102,9 @@ sub DESTROY {
     my ($self) = @_;
     my $orig = $self->{_original};
     chdir $orig if $orig; # should always be so, but just in case...
-    if ( $self->{_tempd} &&
-        !$self->{_preserve} ) {
+    if ( $self->{_tempd}
+        && !$self->{_preserve} )
+    {
         # don't destroy existing $@ if there is no error.
         my $err = do {
             local $@;
@@ -111,49 +117,49 @@ sub DESTROY {
 
 1;
 
-__END__
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 File::pushd - change directory temporarily for a limited scope
 
 =head1 VERSION
 
-version 1.004
+version 1.006
 
 =head1 SYNOPSIS
 
-  use File::pushd;
- 
-  chdir $ENV{HOME};
- 
-  # change directory again for a limited scope
-  {
-      my $dir = pushd( '/tmp' );
-      # working directory changed to /tmp
-  }
-  # working directory has reverted to $ENV{HOME}
- 
-  # tempd() is equivalent to pushd( File::Temp::tempdir )
-  {
-      my $dir = tempd();
-  }
- 
-  # object stringifies naturally as an absolute path
-  {
+ use File::pushd;
+
+ chdir $ENV{HOME};
+
+ # change directory again for a limited scope
+ {
      my $dir = pushd( '/tmp' );
-     my $filename = File::Spec->catfile( $dir, "somefile.txt" );
-     # gives /tmp/somefile.txt
-  }
+     # working directory changed to /tmp
+ }
+ # working directory has reverted to $ENV{HOME}
+
+ # tempd() is equivalent to pushd( File::Temp::tempdir )
+ {
+     my $dir = tempd();
+ }
+
+ # object stringifies naturally as an absolute path
+ {
+    my $dir = pushd( '/tmp' );
+    my $filename = File::Spec->catfile( $dir, "somefile.txt" );
+    # gives /tmp/somefile.txt
+ }
 
 =head1 DESCRIPTION
 
-File::pushd does a temporary C<<< chdir >>> that is easily and automatically
-reverted, similar to C<<< pushd >>> in some Unix command shells.  It works by
+File::pushd does a temporary C<chdir> that is easily and automatically
+reverted, similar to C<pushd> in some Unix command shells.  It works by
 creating an object that caches the original working directory.  When the object
-is destroyed, the destructor calls C<<< chdir >>> to revert to the original working
+is destroyed, the destructor calls C<chdir> to revert to the original working
 directory.  By storing the object in a lexical variable with a limited scope,
 this happens automatically at the end of the scope.
 
@@ -164,19 +170,23 @@ directory from L<File::Temp>.
 For convenience, the object stringifies as the canonical form of the absolute
 pathname of the directory entered.
 
+B<Warning>: if you create multiple C<pushd> objects in the same lexical scope,
+their destruction order is not guaranteed and you might not wind up in the
+directory you expect.
+
 =head1 USAGE
 
-  use File::pushd;
+ use File::pushd;
 
-Using File::pushd automatically imports the C<<< pushd >>> and C<<< tempd >>> functions.
+Using File::pushd automatically imports the C<pushd> and C<tempd> functions.
 
 =head2 pushd
 
-  {
-      my $dir = pushd( $target_directory );
-  }
+ {
+     my $dir = pushd( $target_directory );
+ }
 
-Caches the current working directory, calls C<<< chdir >>> to change to the target
+Caches the current working directory, calls C<chdir> to change to the target
 directory, and returns a File::pushd object.  When the object is
 destroyed, the working directory reverts to the original directory.
 
@@ -185,52 +195,52 @@ called with no arguments, it uses the current directory as its target and
 returns to the current directory when the object is destroyed.
 
 If the target directory does not exist or if the directory change fails
-for some reason, C<<< pushd >>> will die with an error message.
+for some reason, C<pushd> will die with an error message.
 
 Can be given a hashref as an optional second argument.  The only supported
-option is C<<< untaint_pattern >>>, which is used to untaint file paths involved.
-It defaults to C<<< qr{^([-+@\w./]+)$} >>>, which is reasonably restrictive (e.g.
+option is C<untaint_pattern>, which is used to untaint file paths involved.
+It defaults to {qr{^(L<-+@\w./>+)$}}, which is reasonably restrictive (e.g.
 it does not even allow spaces in the path).  Change this to suit your
-circumstances and security needs if running under taint mode. B<Note>: you
+circumstances and security needs if running under taint mode. *Note*: you
 must include the parentheses in the pattern to capture the untainted
 portion of the path.
 
 =head2 tempd
 
-  {
-      my $dir = tempd();
-  }
+ {
+     my $dir = tempd();
+ }
 
-This function is like C<<< pushd >>> but automatically creates and calls C<<< chdir >>> to
+This function is like C<pushd> but automatically creates and calls C<chdir> to
 a temporary directory created by L<File::Temp>. Unlike normal L<File::Temp>
 cleanup which happens at the end of the program, this temporary directory is
-removed when the object is destroyed. (But also see C<<< preserve >>>.)  A warning
+removed when the object is destroyed. (But also see C<preserve>.)  A warning
 will be issued if the directory cannot be removed.
 
-As with C<<< pushd >>>, C<<< tempd >>> will die if C<<< chdir >>> fails.
+As with C<pushd>, C<tempd> will die if C<chdir> fails.
 
 It may be given a single options hash that will be passed internally
-to CE<lt>pushdE<gt>.
+to C<pushd>.
 
 =head2 preserve
 
-  {
-      my $dir = tempd();
-      $dir->preserve;      # mark to preserve at end of scope
-      $dir->preserve(0);   # mark to delete at end of scope
-  }
+ {
+     my $dir = tempd();
+     $dir->preserve;      # mark to preserve at end of scope
+     $dir->preserve(0);   # mark to delete at end of scope
+ }
 
 Controls whether a temporary directory will be cleaned up when the object is
-destroyed.  With no arguments, C<<< preserve >>> sets the directory to be preserved.
+destroyed.  With no arguments, C<preserve> sets the directory to be preserved.
 With an argument, the directory will be preserved if the argument is true, or
-marked for cleanup if the argument is false.  Only C<<< tempd >>> objects may be
-marked for cleanup.  (Target directories to C<<< pushd >>> are always preserved.)
-C<<< preserve >>> returns true if the directory will be preserved, and false
+marked for cleanup if the argument is false.  Only C<tempd> objects may be
+marked for cleanup.  (Target directories to C<pushd> are always preserved.)
+C<preserve> returns true if the directory will be preserved, and false
 otherwise.
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item *
 
@@ -245,7 +255,7 @@ L<File::chdir>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/file-pushd/issues>.
+at L<https://github.com/dagolden/File-pushd/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -253,9 +263,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/file-pushd>
+L<https://github.com/dagolden/File-pushd>
 
-  git clone git://github.com/dagolden/file-pushd.git
+  git clone https://github.com/dagolden/File-pushd.git
 
 =head1 AUTHOR
 
@@ -267,10 +277,15 @@ Diab Jerius <djerius@cfa.harvard.edu>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by David A Golden.
+This software is Copyright (c) 2014 by David A Golden.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
+
+__END__
+
+
+# vim: ts=4 sts=4 sw=4 et:
